Airport class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

Airport({String? id, String? iataCode, String? faaCode, String? icaoCode, String? name, String? alternates, Market? market, String? city, String? region, String? latitude, String? longitude, int? altitude, int? sequence})
Airport.fromJson(Map<String, dynamic> json)
factory

Properties

alternates → String?
final
altitude → int?
final
city → String?
final
faaCode → String?
final
hashCode → int
The hash code for this object.
no setterinherited
iataCode → String?
final
icaoCode → String?
final
id → String?
final
latitude → String?
final
longitude → String?
final
market → Market?
final
name → String?
final
region → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequence → int?
final

Methods

copyWith({String? id, String? iataCode, String? faaCode, String? icaoCode, String? name, String? alternates, Market? market, String? city, String? region, String? latitude, String? longitude, int? altitude, int? sequence}) → Airport

Available on Airport, provided by the $AirportExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(dynamic other) → bool
The equality operator.
override

Constants

fromJsonFactory → const Airport Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(Airport instance)