CrewRating class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

CrewRating({int? id, DateTime? dbDateCreated, DateTime? dbDateUpdated, int? crew, int? crewPosition, int? rosterPosition, double? rating, User? userRated, DateTime? dateRated, DateTime? dateHidden, CrewRatingType? type, String? notes})
CrewRating.fromJson(Map<String, dynamic> json)
factory

Properties

crew → int?
final
crewPosition → int?
final
dateHidden → DateTime?
final
dateRated → DateTime?
final
dbDateCreated → DateTime?
final
dbDateUpdated → DateTime?
final
hashCode → int
The hash code for this object.
no setterinherited
id → int?
final
notes → String?
final
rating → double?
final
rosterPosition → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → CrewRatingType?
final
userRated → User?
final

Methods

copyWith({int? id, DateTime? dbDateCreated, DateTime? dbDateUpdated, int? crew, int? crewPosition, int? rosterPosition, double? rating, User? userRated, DateTime? dateRated, DateTime? dateHidden, CrewRatingType? type, String? notes}) → CrewRating

Available on CrewRating, provided by the $CrewRatingExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(dynamic other) → bool
The equality operator.
override

Constants

fromJsonFactory → const CrewRating Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(CrewRating instance)