CrewSettingsTravel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

CrewSettingsTravel({bool? executive, CrewSettingsTravelGender? gender, Object? frequentFlyers, Object? hotelRewards, Object? rentalCars, String? redress, String? tsaPrecheck, List<CrewSettingsTravelPreferredAirlines>? preferredAirlines, CrewSettingsTravelTravelSeatingPreference? travelSeatingPreference, List<CrewSettingsTravelMealPreferences>? mealPreferences, List<Passport>? passportList})
CrewSettingsTravel.fromJson(Map<String, dynamic> json)
factory

Properties

executive → bool?
final
frequentFlyers → Object?
final
gender → CrewSettingsTravelGender?
final
hashCode → int
The hash code for this object.
no setterinherited
hotelRewards → Object?
final
mealPreferences → List<CrewSettingsTravelMealPreferences>?
final
passportList → List<Passport>?
final
preferredAirlines → List<CrewSettingsTravelPreferredAirlines>?
final
redress → String?
final
rentalCars → Object?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
travelSeatingPreference → CrewSettingsTravelTravelSeatingPreference?
final
tsaPrecheck → String?
final

Methods

copyWith({bool? executive, CrewSettingsTravelGender? gender, Object? frequentFlyers, Object? hotelRewards, Object? rentalCars, String? redress, String? tsaPrecheck, List<CrewSettingsTravelPreferredAirlines>? preferredAirlines, CrewSettingsTravelTravelSeatingPreference? travelSeatingPreference, List<CrewSettingsTravelMealPreferences>? mealPreferences, List<Passport>? passportList}) → CrewSettingsTravel

Available on CrewSettingsTravel, provided by the $CrewSettingsTravelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(dynamic other) → bool
The equality operator.
override

Constants

fromJsonFactory → const CrewSettingsTravel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(CrewSettingsTravel instance)