EventAccountUserRoleRelationshipsGet$Response class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Properties

count → int?
final
hashCode → int
The hash code for this object.
no setterinherited
next → String?
final
previous → String?
final
results → List<EventAccountUserRoleRelationship>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? count, String? next, String? previous, List<EventAccountUserRoleRelationship>? results}) → EventAccountUserRoleRelationshipsGet$Response

Available on EventAccountUserRoleRelationshipsGet$Response, provided by the $EventAccountUserRoleRelationshipsGet$ResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(dynamic other) → bool
The equality operator.
override

Constants

fromJsonFactory → const EventAccountUserRoleRelationshipsGet$Response Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(EventAccountUserRoleRelationshipsGet$Response instance)