Passport class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

Passport({String? country, String? expiry, String? number})
Passport.fromJson(Map<String, dynamic> json)
factory

Properties

country → String?
final
expiry → String?
final
hashCode → int
The hash code for this object.
no setterinherited
number → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? country, String? expiry, String? number}) → Passport

Available on Passport, provided by the $PassportExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(dynamic other) → bool
The equality operator.
override

Constants

fromJsonFactory → const Passport Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(Passport instance)