Vendor class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

Vendor({int? id, DateTime? dbDateCreated, DateTime? dbDateUpdated, String? code, String? externalCode, String? name, VendorStatus? status, String? email, VendorKind? kind, String? usState})
Vendor.fromJson(Map<String, dynamic> json)
factory

Properties

code → String?
final
dbDateCreated → DateTime?
final
dbDateUpdated → DateTime?
final
email → String?
final
externalCode → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → int?
final
kind → VendorKind?
final
name → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → VendorStatus?
final
usState → String?
final

Methods

copyWith({int? id, DateTime? dbDateCreated, DateTime? dbDateUpdated, String? code, String? externalCode, String? name, VendorStatus? status, String? email, VendorKind? kind, String? usState}) → Vendor

Available on Vendor, provided by the $VendorExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(dynamic other) → bool
The equality operator.
override

Constants

fromJsonFactory → const Vendor Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(Vendor instance)