Venue class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

Venue({int? id, DateTime? dbDateCreated, DateTime? dbDateUpdated, String? code, String? externalCode, String? name, VenueStatus? status, List<int>? rooms, List<int>? notes, List<int>? contacts, String? street1, String? street2, String? street3, String? locality, String? region, String? postalCode, String? country, String? phone, String? airport, int? market})
Venue.fromJson(Map<String, dynamic> json)
factory

Properties

airport → String?
final
code → String?
final
contacts → List<int>?
final
country → String?
final
dbDateCreated → DateTime?
final
dbDateUpdated → DateTime?
final
externalCode → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → int?
final
locality → String?
final
market → int?
final
name → String?
final
notes → List<int>?
final
phone → String?
final
postalCode → String?
final
region → String?
final
rooms → List<int>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → VenueStatus?
final
street1 → String?
final
street2 → String?
final
street3 → String?
final

Methods

copyWith({int? id, DateTime? dbDateCreated, DateTime? dbDateUpdated, String? code, String? externalCode, String? name, VenueStatus? status, List<int>? rooms, List<int>? notes, List<int>? contacts, String? street1, String? street2, String? street3, String? locality, String? region, String? postalCode, String? country, String? phone, String? airport, int? market}) → Venue

Available on Venue, provided by the $VenueExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(dynamic other) → bool
The equality operator.
override

Constants

fromJsonFactory → const Venue Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(Venue instance)