VenueContact class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

VenueContact({int? id, DateTime? dbDateCreated, DateTime? dbDateUpdated, VenueContactType? type, int? venue, String? firstName, String? lastName, String? email, String? mobile, String? phone, String? extension, String? fax, String? companyName, String? jobTitle})
VenueContact.fromJson(Map<String, dynamic> json)
factory

Properties

companyName → String?
final
dbDateCreated → DateTime?
final
dbDateUpdated → DateTime?
final
email → String?
final
extension → String?
final
fax → String?
final
firstName → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → int?
final
jobTitle → String?
final
lastName → String?
final
mobile → String?
final
phone → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → VenueContactType?
final
venue → int?
final

Methods

copyWith({int? id, DateTime? dbDateCreated, DateTime? dbDateUpdated, VenueContactType? type, int? venue, String? firstName, String? lastName, String? email, String? mobile, String? phone, String? extension, String? fax, String? companyName, String? jobTitle}) → VenueContact

Available on VenueContact, provided by the $VenueContactExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(dynamic other) → bool
The equality operator.
override

Constants

fromJsonFactory → const VenueContact Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(VenueContact instance)