VenueRoom class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

VenueRoom({int? id, DateTime? dbDateCreated, DateTime? dbDateUpdated, String? name, int? venue, String? dimensions})
VenueRoom.fromJson(Map<String, dynamic> json)
factory

Properties

dbDateCreated → DateTime?
final
dbDateUpdated → DateTime?
final
dimensions → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → int?
final
name → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
venue → int?
final

Methods

copyWith({int? id, DateTime? dbDateCreated, DateTime? dbDateUpdated, String? name, int? venue, String? dimensions}) → VenueRoom

Available on VenueRoom, provided by the $VenueRoomExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(dynamic other) → bool
The equality operator.
override

Constants

fromJsonFactory → const VenueRoom Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(VenueRoom instance)